@@ -6,7 +6,7 @@ class BaseMultiTaskGGMethod(BaseMethod):
 
 
 class Naive(BaseMultiTaskGGMethod):
-    def __init__(self):
+    def __init__(self, **kwargs):
         super().__init__()
 
     def set_task(self, **kwargs):
