@@ -18,7 +18,9 @@ class SupermaskSuperposition(BaseMultiTaskGGMethod):
     primaryClass={cs.LG}
     }
     """
-    def __init__(self, backbone: nn.Module, pruning_percentage: float):
+    def __init__(self, backbone: nn.Module,
+                 pruning_percentage: float,
+                 **kwargs):
         super().__init__()
         self.pruning_percentage = pruning_percentage
         self.apply_wrapper_to_model(model=backbone)
@@ -32,31 +34,6 @@ class SupermaskSuperposition(BaseMultiTaskGGMethod):
                                                        self.pruning_percentage))
             self.apply_wrapper_to_model(module)
 
-        # for name, module in model.named_modules():
-        #     if isinstance(module, (nn.Linear, nn.Conv2d)):
-        #         l = getattr(model, name)
-        #         setattr(model, name, BElayer(l))
-
-    # def get_parameters(self, task: SupervisedTask, backbone: nn.Module, solver: Solver):
-    #     parameters = []
-    #     current_task = task.index
-    #
-    #     if current_task == 0:
-    #         parameters.extend(backbone.parameters())
-    #     else:
-    #         for n, m in backbone.named_modules():
-    #             if isinstance(m, BElayer):
-    #                 parameters.append(m.tasks_alpha[current_task])
-    #                 parameters.append(m.tasks_gamma[current_task])
-    #             elif isinstance(m, BatchNorm2d):
-    #                 m.track_running_stats = False
-    #                 # parameters.append(m.parameters())
-    #
-    #     if isinstance(solver, MultiHeadsSolver):
-    #         parameters.extend(solver.heads[current_task].parameters())
-    #
-    #     return parameters
-
     def set_task(self, backbone: nn.Module, task: SupervisedTask, **kwargs):
         task_i = task.index
         for n, m in backbone.named_modules():
@@ -69,4 +46,3 @@ class SupermaskSuperposition(BaseMultiTaskGGMethod):
             if isinstance(m, SupSupMaskWrapper):
                 m.add_task()
                 m.set_current_task(task_i)
-                # parameters.append(m.tasks[current_task])
